/***************************************************************************
*                 _                                _                       *
*                /_\         Chess Board          /_\                      *
*                \_/      -------------------     \_/                      *
*                /_\           Settings           /_\                      *
*                |_|      -------------------     |_|                      *
*               /___\      GNU GPL Version 2     /___\                     *
*                                                                          *
***************************************************************************/
/* Header Files */
#include "setting.h"
/* Window */
static WINDOW *winM;
/* File Open */
FILE *cboard;
FILE *conf;
/* Settings */
int nround = 0;
char white[30];
char black[30];
char nevent[30] = "Chess Board Match";
char nsite[30] = "GWOS";

/*---------------------------------------------------------------------------*/

/* Draw Chess Board */
void settings(char *ipadr, char *chess)
{
	/* Date */
	initscr();
	attrset(use_default_colors());
	strftime(ndate, DATE, "%Y.%m.%d", date_Board());
	/* Settings */
	colour_Board();	
	attrset(A_NORMAL);
	getmaxyx(stdscr, VERT, HORI);
	mvhline(1,0,ACS_HLINE,HORI);
	mvhline(23,0,ACS_HLINE,HORI);

	/* Chess Settings */
	nround++;
	mvprintw(4,3,"Event:   %s",nevent);
	mvprintw(5,3,"Site:    %s",nsite);
	mvprintw(6,3,"Date:    %s",ndate);
	mvprintw(7,3,"Round:   %d",nround);
	mvprintw(8,3,"Result:  %c-%c",wboard.result,bboard.result);

	/*-------------------------------------------------------------------*/

	/* Game Settings */
	mvprintw(13,3,"Chess Clock        <     >");
	mvprintw(14,3,"PGN File           <     >");
	mvprintw(15,3,"UCI Protocol       <     >");
	mvprintw(16,3,"Network            <     >");
	attrset(COLOR_PAIR(11));
	mvprintw(13,24,"NOT");
	mvprintw(14,24,"NOT");
	mvprintw(15,24,"NOT");
	mvprintw(16,24,"NOT");
	attrset(COLOR_PAIR(10));

	/*-------------------------------------------------------------------*/
	
	/* Functions */
	clockmode();
	ucimode();
	pgnmode();
	windows();
	
	/*-------------------------------------------------------------------*/
	
	/* Network */
	if(chess[4] || chess[5])
	{
		attrset(COLOR_PAIR(10));
		mvprintw(16,24,"YES");
	}

	/* Player */
	attrset(A_NORMAL);
	mvprintw(10,3,"White:  ");
	getstr(white);
	mvprintw(11,3,"Black:  ");
	getstr(black);
	
	/* Client Ready */
	if(chess[5])
	{	
		mvprintw(17,3,"Client             <     >");
		attrset(COLOR_PAIR(10));
		mvprintw(17,24,"YES");
		attrset(A_NORMAL);
		mvprintw(19,3,"Server IP: ");
		getstr(ipadr);
	}
	/* Server Ready */
	if(chess[4])
	{	
		mvprintw(17,3,"Server             <     >");
		attrset(COLOR_PAIR(10));
		mvprintw(17,24,"YES");
	}
	delwin(winM);
	refresh();
	clear();
}

/*---------------------------------------------------------------------------*/

/* Clock Mode */
void clockmode()
{
	/* Settings */
	wboard.time = 7200;
	bboard.time = 7200;
	eboard.time = 7200;
	
	/* Chess Clock */
	if((eboard.time == wboard.time) && (eboard.time == bboard.time))
	{
		mvprintw(13,24,"YES");
	}
}

/*---------------------------------------------------------------------------*/

/* UCI Engine */
void ucimode()
{
	/* Engine in UCI Mode */
	eboard.uci = TRUE;
	if(eboard.uci)
	{
		/* The Engine is ready */
		eboard.uciok = TRUE;
		mvprintw(15,24,"YES");
	}
	/* Waiting for the Engine */
	eboard.isready = TRUE;
	if(eboard.isready)
	{	
		/* Engine has finished */
		eboard.readyok = TRUE;
		mvprintw(15,24,"YES");
	}
	/* Searching for a Game */
	eboard.ucinewgame = TRUE;
}

/*---------------------------------------------------------------------------*/

/* PGN File */
void pgnmode()
{
	/* PGN Log File Open */
	cboard=fopen("/var/log/cboard/chess.pgn","r+");
	if(cboard != NULL)
	{
		mvprintw(14,24,"YES");
	}
	
	/* Write Text File */
	fprintf(cboard,"[Event \"%s\"]\n",nevent);
	fprintf(cboard,"[Site \"%s\"]\n",nsite);
	fprintf(cboard,"[Date \"%s\"]\n",ndate);
	fprintf(cboard,"[Round \"%d\"]\n",nround);
	fprintf(cboard,"[White \"%s\"]\n",white);	
	fprintf(cboard,"[Black \"%s\"]\n",black);
	fprintf(cboard,"[TimeControl \"%d+0\"]\n",eboard.time);
	fprintf(cboard,"[Result \"%c-%c\"]\n\n\n\n",wboard.result,bboard.result);
	/* Chess File Close */
	fclose(cboard);
}

/*---------------------------------------------------------------------------*/

/* Windows */
void windows()
{
	initscr();
	winM = newwin(21,43,2,35);
	attrset(use_default_colors());
	box(winM,ACS_VLINE,ACS_HLINE);
	mvwprintw(winM, 1,2,"  | a | b | c | d | e | f | g | h |   ");
	mvwprintw(winM, 2,2,"--+---+---+---+---+---+---+---+---+---");
	mvwprintw(winM, 3,2," 8  a8  b8  c8  d8  e8  f8  g8  h8  8 ");
	mvwprintw(winM, 5,2," 7  a7  b7  c7  d7  e7  f7  g7  h7  7 ");
	mvwprintw(winM, 7,2," 6  a6  b6  c6  d6  e6  f6  g6  h6  6 ");
	mvwprintw(winM, 9,2," 5  a5  b5  c5  d5  e5  f5  g5  h5  5 ");
	mvwprintw(winM,11,2," 4  a4  b4  c4  d4  e4  f4  g4  h4  4 ");
	mvwprintw(winM,13,2," 3  a3  b3  c3  d3  e3  f3  g3  h3  3 ");
	mvwprintw(winM,15,2," 2  a2  b2  c2  d2  e2  f2  g2  h2  2 ");
	mvwprintw(winM,17,2," 1  a1  b1  c1  d1  e1  f1  g1  h1  1 ");
	mvwprintw(winM,18,2,"--+---+---+---+---+---+---+---+---+---");
	mvwprintw(winM,19,2,"  | a | b | c | d | e | f | g | h | ");
	touchwin(winM);
	wrefresh(winM);
}

/*---------------------------------------------------------------------------*/

